<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  端末識別番号を取得（取得出来なかった場合は空文字を返却）
 *
 *  @access public
 */
function pocket_mobileId()
{
    $id = '';
    $ua = $_SERVER['HTTP_USER_AGENT'];

    // DoCoMo
    if (!strncmp($ua, 'DoCoMo', 6))
    {
        // mova
        if (substr($ua, 7, 3) == '1.0')
        {
            $ser = array_pop(explode('/', $ua));
            if (!strncmp($ser, 'ser', 3))
                $id = $ser;
        }
        // FOMA
        elseif (substr($ua, 7, 3) == '2.0')
        {
            $icc = substr($ua, -24, -1);
            if (!strncmp($icc, 'icc', 3))
                $id = $icc;
        else{$id = $icc;}
        }
    }
    // Vodafone(PDC)
    elseif (!strncmp($ua, 'J-PHONE', 7))
    {
        $pieces = explode('/', $ua);
        $piece_sn = explode(' ', $pieces[3]);
        $sn = array_shift($piece_sn);
        if (!strncmp($sn, 'SN', 2))
            $id = $sn;
    }
    // Vodafone(3G)
    // SoftBank
    // Up.Browser を搭載しているものがある(auより先に評価)
    elseif (!strncmp($ua, 'Vodafone', 8)
        || !strncmp($ua, 'SoftBank', 8))
    {
        $pieces = explode('/', $ua);
        $piece_sn = explode(' ', $pieces[4]);
        $sn = array_shift($piece_sn);
        if (!strncmp($sn, 'SN', 2))
            $id = $sn;
    }
    // MOT
    elseif (!strncmp($ua, 'MOT', 3))
    {
        // MOTは製造番号を取得できない
    }
    // au
    elseif (!strncmp($ua, 'KDDI', 4)
        || !strncasecmp($ua, 'up.browser', 10))
    {
        if ($_SERVER['HTTP_X_UP_SUBNO'])
            $id = $_SERVER['HTTP_X_UP_SUBNO'];
    }

    return $id;
}

/**
 *  携帯文字列をエンコーディング
 *
 *  @access public
 *  @param  array   $data               配列
 */
function pocket_mobileEncoding($data)
{
   return is_array($data) ?
               array_map('pocket_mobileEncoding', $data) :
               mb_convert_encoding(pocket_emojiEncoding($data), 'UTF-8', 'SJIS');
}

/**
 *  携帯絵文字をエンコーディング
 *
 *  @access public
 *  @param  array   $data               配列
 */
function pocket_emojiEncoding($data)
{
    // User-Agentを判定
    $uaj = new UAJudgment();

    // DoCoMo
    if ($uaj->isDocomo())
    {
        return pocket_emojiEncoding_d($data);
    }
    // Vodafone・SoftBank
    elseif ($uaj->isVodafone())
    {
        return pocket_emojiEncoding_v($data);
    }
    // au
    elseif ($uaj->isAu())
    {
        return pocket_emojiEncoding_a($data);
    }

    return $data;
}

/**
 *  DoCoMo端末の携帯絵文字をエンコーディング
 *
 *  @access public
 *  @param  array   $data               配列
 */
function pocket_emojiEncoding_d($data)
{
   return is_array($data) ?
               array_map('pocket_emojiEncoding_d', $data) :
               pocket_emojiDelete_d($data);
}

/**
 *  Vodafone端末の携帯絵文字をエンコーディング
 *
 *  @access public
 *  @param  array   $data               配列
 */
function pocket_emojiEncoding_v($data)
{
   return is_array($data) ?
               array_map('pocket_emojiEncoding_v', $data) :
               pocket_emojiDelete_v($data);
}

/**
 *  au端末の携帯絵文字をエンコーディング
 *
 *  @access public
 *  @param  array   $data               配列
 */
function pocket_emojiEncoding_a($data)
{
   return is_array($data) ?
               array_map('pocket_emojiEncoding_a', $data) :
               pocket_emojiDelete_a($data);
}

/**
 *  DoCoMo端末の絵文字を削除
 *
 *  @access public
 *  @param  array   $value              配列
 */
function pocket_emojiDelete_d($value)
{
    $value = unpack('C*', $value);
    $len = count($value);
    $buff = '';
    $n = 1;

    while ($n <= $len)
    {
        $ch1 = $value[$n];
        $ch2 = $value[$n+1];
        if ((($ch1 == 0xF8) && (0x9F <= $ch2) && ($ch2 <= 0xFC)) ||
            (($ch1 == 0xF9) &&
            ((0x40 <= $ch2) && ($ch2 <= 0x49) ||
            (0x50 <= $ch2) && ($ch2 <= 0x52) ||
            (0x55 <= $ch2) && ($ch2 <= 0x57) ||
            (0x5B <= $ch2) && ($ch2 <= 0x5E) ||
            (0x72 <= $ch2) && ($ch2 <= 0x7E) ||
            (0x80 <= $ch2) && ($ch2 <= 0xB0))))
        {
            $n++;
        }
        elseif (($ch1 == 0xF9) && (0xB1 <= $ch2) && ($ch2 <= 0xFC))
        {
            $n++;
        }
        elseif (((0x81 <= $ch1) && ($ch1 <= 0x9f) ) || ((0xe0 <= $ch1) && ($ch1 <= 0xfc)))
        {
            $buff .= pack('C', $ch1) . pack('C', $ch2);
            $n++;
        }
        else
        {
            $buff .= pack('C', $ch1);
        }
        $n++;
    }

    return $buff;
}

/**
 *  Vodafone端末の絵文字を削除
 *
 *  @access public
 *  @param  array   $value              配列
 */
function pocket_emojiDelete_v($value)
{
    $value = preg_split('/\x1B[\x24]([\x21-\x7A]{2,})\x0F/', $value, -1, PREG_SPLIT_DELIM_CAPTURE);
    $line = count($value);
    $buff = '';
    $n = 0;

    while ($n < $line)
    {
        if (!$n % 2)
        {
            $buff .= $value[$n];
        }
        $n++;
    }

    return $buff;
}

/**
 *  au端末の絵文字を削除
 *
 *  @access public
 *  @param  array   $value              配列
 */
function pocket_emojiDelete_a($value)
{
    $value = unpack('C*', $value);
    $len = count($value);
    $buff = '';
    $n = 1;

    while ($n <= $len)
    {
        $ch1 = $value[$n];
        $ch2 = $value[$n+1];
        if ((($ch1 == 0xF8) && (0x9F <= $ch2) && ($ch2 <= 0xFC)) ||
            (($ch1 == 0xF9) &&
            ((0x40 <= $ch2) && ($ch2 <= 0x49) ||
            (0x50 <= $ch2) && ($ch2 <= 0x52) ||
            (0x55 <= $ch2) && ($ch2 <= 0x57) ||
            (0x5B <= $ch2) && ($ch2 <= 0x5E) ||
            (0x72 <= $ch2) && ($ch2 <= 0x7E) ||
            (0x80 <= $ch2) && ($ch2 <= 0xB0))))
        {
            $n++;
        }
        elseif (($ch1 == 0xF9) && (0xB1 <= $ch2) && ($ch2 <= 0xFC))
        {
            $n++;
        }
        elseif (((0x81 <= $ch1) && ($ch1 <= 0x9f) ) || ((0xe0 <= $ch1) && ($ch1 <= 0xfc)))
        {
            $buff .= pack('C', $ch1) . pack('C', $ch2);
            $n++;
        }
        else
        {
            $buff .= pack('C', $ch1);
        }
        $n++;
    }

    return $buff;
}

?>
